## Analyse-Syntax für das Beispiel-Strukturgleichungsmodell zu Burnout aus:
## Werner, C. S., Schermelleh-Engel, K., Gerhard, C. & Gäde, J. C. (2016). 
## Strukturgleichungsmodelle. In N. Döring & J. Bortz, Forschungsmethoden und
## Evaluation (5. Aufl., S. 945-973). Berlin: Springer.
## doi:10.1007/978-3-642-41089-5_17

## Analyse mit der freien Statistik-Umgebung R (http://www.r-project.org/)
## und dem lavaan-Paket für Strukturgleichungsmodelle (http://lavaan.org/)
## (für lavaan 0.5-20/November 2015; Aktualisierung ggf. im Webangebot zum Buch)

## Mit # beginnende Zeilen enthalten Kommentare.

## R-Paket "lavaan" für Strukturgleichungsmodelle installieren
## (nur einmalig; sobald das Paket installiert ist, kann die
## install.packages()-Anweisung mit # vor der Zeile auskommentiert werden)

install.packages("lavaan")

## lavaan-Paket für Strukturgleichungsmodelle laden (bei jeder Analyse)

library("lavaan")

## Datendatei einlesen: In der ersten Zeile (header) stehen die Variablennamen

burnout.daten <- read.table("burnout_beispieldaten.dat", header=TRUE)

## Struktur der Daten anschauen: 260 Fälle, 10 Variablen 

str(burnout.daten)

## Modell definieren: Zwei exogene latente Variablen
## (Prädiktor-Konstrukte) Perfektionismus und Arbeitsanforderungen,
## zwei endogene latente Variablen (Mediator-/Kriteriums-Konstrukte)
## Overcommitment und Burnout
## Die Modelldefinition steht in einfachen Anführungszeichen '.
## Das Symbol =~ bedeutet "wird gemessen durch",
## das Symbol ~ bedeutet "wird vorhergesagt durch".

burnout.modell <- '

 # Messmodelle
  perfektionismus =~ standards + selbstkritik + alles.nichts
  anforderungen   =~ menge + zeitdruck
  overcommitment  =~ aufopferung + nicht.abschalten + gruebeln
  burnout         =~ erschoepfung + depersonalisation 

 # Strukturmodell
  overcommitment  ~  perfektionismus + anforderungen
  burnout         ~  overcommitment + anforderungen
'

## Modell analysieren mit der Funktion sem()

burnout.analyse <- sem(burnout.modell, data=burnout.daten)

## Ergebnisse ausgeben einschliesslich Gütekriterien 
## und standardisierter Parameterschätzungen

summary(burnout.analyse, fit.measures=TRUE, standardized=TRUE)

## Auf Wunsch werden noch ausführlichere Ergebnisse ausgegeben;
## bei Bedarf Kommentarzeichen vor den folgenden beiden Zeilen entfernen:

# summary(burnout.analyse,
#         fit.measures=TRUE, standardized=TRUE, rsquare=TRUE, modindices=TRUE)
